HunterDeadlyDecoyWindow = class(Turbine.UI.Window);

function HunterDeadlyDecoyWindow:Constructor()
    Turbine.UI.Window.Constructor(self);

    screenWidth, screenHeight = Turbine.UI.Display:GetSize();

    self:SetSize(40, 48); -- 1 x 1.2
    self:SetPosition(
        SETTINGS.WINDOW.LEFT * screenWidth,
        SETTINGS.WINDOW.TOP * screenHeight);
    self:SetZOrder(0x0FFFFFFF);
    self.isUnlocked = false;

    self.imageControl = Turbine.UI.Control();
    self.imageControl:SetParent(self);
    self.imageControl:SetSize(32, 32);
    self.imageControl:SetBackground("CubePlugins/HunterDeadlyDecoy/Resources/DeadlyDecoy.tga");

    self.timerControl = Turbine.UI.Control();
    self.timerControl:SetParent(self);
    self.timerControl:SetSize(32, 5);
    self.timerControl:SetTop(36);
    self.timerControl:SetBackColor(Turbine.UI.Color.White);
    self.timerControl.startTime = 0;
    self.timerControl.Update = function(sender, args)
        local currentTime = Turbine.Engine.GetGameTime();

        local deltaTime = currentTime - self.timerControl.startTime;

        if (deltaTime > self.timerControl.expireTime) then
            self:Hide();
        else
            local barWidth = 32 - (deltaTime / self.timerControl.expireTime * 32);
            self.timerControl:SetWidth(barWidth);
        end
    end

    self.healthControl = Turbine.UI.Control();
    self.healthControl:SetParent(self);
    self.healthControl:SetSize(32, 5);
    self.healthControl:SetTop(42);
    self.healthControl:SetBackColor(Turbine.UI.Color.LimeGreen);

    self:SetStretchMode(1);
    local scaledWidth = SETTINGS.WINDOW.WIDTH * screenWidth;
    local scaledHeight = scaledWidth * 1.2;
    self:SetSize(scaledWidth, scaledHeight);

    self:SetMouseVisible(isVisible);
    self.imageControl:SetMouseVisible(isVisible);
    self.timerControl:SetMouseVisible(isVisible);
    self.healthControl:SetMouseVisible(isVisible);

    self.MouseDown = function(sender, args)
        self.mouseDown_MousePosition = { Turbine.UI.Display.GetMousePosition(); }
        self.mouseDown_WindowPosition = { self:GetPosition(); }
        self.isMouseDown = true;
    end

    self.MouseUp = function(sender, args)
        self.isMouseDown = false;
    end

    self.MouseMove = function(sender, args)
        if (self.isMouseDown) then
            local mouseDownX, mouseDownY = unpack(self.mouseDown_MousePosition);
            local windowLeft, windowTop = unpack(self.mouseDown_WindowPosition);
            local mouseCurrentX, mouseCurrentY = Turbine.UI.Display.GetMousePosition();

            -- calculate how much the cursor has moved
            local deltaX = mouseCurrentX - mouseDownX;
            local deltaY = mouseCurrentY - mouseDownY;

            -- move the window the same distance that the mouse has moved:
            self:SetPosition(windowLeft + deltaX, windowTop + deltaY);

            local screenWidth, screenHeight = Turbine.UI.Display:GetSize();
            SETTINGS.WINDOW.LEFT = self:GetLeft() / screenWidth;
            SETTINGS.WINDOW.TOP = self:GetTop() / screenHeight;

        end
    end

end

function HunterDeadlyDecoyWindow:SetAllMouseVisible(isVisible)
    self:SetMouseVisible(isVisible);
end

function HunterDeadlyDecoyWindow:UnlockForMoving()
    self.isUnlocked = true;
    self.timerControl:SetWidth(32);
    self.healthControl:SetWidth(32);

    self:SetVisible(true);
    self:SetAllMouseVisible(true);
end

function HunterDeadlyDecoyWindow:LockForMoving()
    self.isUnlocked = false;

    self:SetVisible(false);
    self:SetAllMouseVisible(false);
end

function HunterDeadlyDecoyWindow:Show(isDeadly)
    if (self.isUnlocked) then return; end

    self:SetVisible(true);

    self.timerControl:SetWidth(32);
    self.timerControl.startTime = Turbine.Engine.GetGameTime();
    if (isDeadly) then
        self.timerControl.expireTime = 15;
    else
        self.timerControl.expireTime = 60;
    end
    self.timerControl:SetWantsUpdates(true);

    -- Get the max morale for decoy
    local currentLevel = localPlayer:GetLevel();
    local decoyMaxHealth = _DEADLY_DECOY_MAX_HEALTH_PER_CHAR_LEVEL[currentLevel];
    if (decoyMaxHealth == nil) then
        self.healthControl.decoyMaxHealth = 0;
        self.healthControl:SetWidth(0);
    else
        self.healthControl.decoyMaxHealth = decoyMaxHealth;
        self.healthControl.decoyCurrentHealth = decoyMaxHealth;
        self.healthControl:SetWidth(32);
    end

end

function HunterDeadlyDecoyWindow:Hide()
    if (self.isUnlocked) then return; end

    self:SetVisible(false);
    self.timerControl:SetWantsUpdates(false);
end

function HunterDeadlyDecoyWindow:DecoyDamage(damageAmount)
    if (self.isUnlocked) then return; end

    if (self.healthControl.decoyMaxHealth == 0) then return; end

    self.healthControl.decoyCurrentHealth = 
        self.healthControl.decoyCurrentHealth - tonumber(damageAmount);

    if (self.healthControl.decoyCurrentHealth <= 0) then
        -- health is <= 0, decoy died :(
        self:Hide();
    else
        -- health is > 0, update bar
        local percent = 
            self.healthControl.decoyCurrentHealth / 
            self.healthControl.decoyMaxHealth;
        local barWidth = (percent * 32);
        self.healthControl:SetWidth(barWidth);
    end
end